# -*- coding: utf-8 -*-

# Authors: Diego Sarmentero <diego.sarmentero@canonical.com>
#
# Copyright 2011 Canonical Ltd.
#
# This program is free software: you can redistribute it and/or modify it
# under the terms of the GNU General Public License version 3, as published
# by the Free Software Foundation.
#
# This program is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranties of
# MERCHANTABILITY, SATISFACTORY QUALITY, or FITNESS FOR A PARTICULAR
# PURPOSE.  See the GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License along
# with this program.  If not, see <http://www.gnu.org/licenses/>.

"""Customized Check Box to support links."""

from PyQt4 import QtGui


class EnhancedCheckBox(QtGui.QCheckBox):
    """Enhanced QCheckBox to support links in the message displayed."""

    def __init__(self, text=""):
        QtGui.QCheckBox.__init__(self)
        hbox = QtGui.QHBoxLayout()
        self.text_label = QtGui.QLabel(text)
        self.text_label.setOpenExternalLinks(True)
        padding = self.iconSize().width()
        self.text_label.setStyleSheet("padding-left: {0}px;".format(padding))
        hbox.addWidget(self.text_label)
        self.setLayout(hbox)

        self.stateChanged.connect(self.text_label.setFocus)

    def text(self):
        """Return the text of this widget."""
        return self.text_label.text()

    # Invalid name "setText"
    # pylint: disable=C0103

    def setText(self, text):
        """Set a new text to this widget."""
        self.text_label.setText(text)

    # pylint: enable=C0103
