# -*- coding: utf-8 -*-

# Authors: Manuel de la Pena <manuel@canonical.com>
#          Roberto Alsina <roberto.alsina@canonical.com>
#
# Copyright 2011 Canonical Ltd.
#
# This program is free software: you can redistribute it and/or modify it
# under the terms of the GNU General Public License version 3, as published
# by the Free Software Foundation.
#
# This program is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranties of
# MERCHANTABILITY, SATISFACTORY QUALITY, or FITNESS FOR A PARTICULAR
# PURPOSE.  See the GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License along
# with this program.  If not, see <http://www.gnu.org/licenses/>.
"""Reactor installation for windows."""

# pylint: disable=E1101, F0401, W0404

import sys

from PyQt4 import QtGui, QtCore
from twisted.internet import defer

# Module used to include the resources into this file
# pylint: disable=W0611
from ubuntuone_installer.gui.qt.ui import images_rc
# pylint: enable=W0611
from ubuntuone_installer.gui.qt import utils


def stop(*args):
    """End the process."""
    from twisted.internet import reactor
    reactor.stop()


def error_cb(exc, logger):
    """Handle credentials errors."""
    logger.error(
    'Error while getting the credentials: %r', exc)
    stop()


@defer.inlineCallbacks
def success_cb(creds, gui, installing, logger):
    """Handle credentials success."""
    logger.debug('Got back from sso.')
    if creds:  # Have credentials already
        logger.debug('Already got credentials.')
        logger.info('Starting control panel.')
        utils.start_control_panel(with_icon=False)
        logger.info('Checking updates.')
        yield check_updates(gui, logger)
        logger.info('Stopping.')
        stop()
    else:  # No credentials
        logger.debug('Did got connections.')
        window = gui.MainWindow(close_callback=stop, installing=installing)
        # Set Application Style Sheet
        app = QtGui.QApplication.instance()
        qss = QtCore.QResource(":/ubuntuone.qss")
        app.setStyleSheet(QtCore.QString(qss.data()))
        # Apply font to the entire application
        QtGui.QFontDatabase.addApplicationFont(':/Ubuntu-R.ttf')
        QtGui.QFontDatabase.addApplicationFont(':/Ubuntu-B.ttf')
        # Set Application Icon
        app.setWindowIcon(QtGui.QIcon(":/ubuntu_one_favicon.png"))
        window.show()


@defer.inlineCallbacks
def check_credentials(credentials_tool, gui, logger,
                      installer=False):
    """Check credentials and either start u1cp or show the wizard."""
    credtool = credentials_tool()
    # pylint: disable=W0703
    try:
        creds = yield credtool.find_credentials()
    except Exception, exc:
        error_cb(exc, logger)
    else:
        yield success_cb(creds, gui, installer, logger)


@defer.inlineCallbacks
def check_updates(gui, logger):
    """Check for updates."""
    logger.info('Checking for updates.')
    # the idea is simple, check if there are updates, ask user if we perform
    # the update and continue.
    are_updates_present = yield utils.are_updates_present(logger)
    logger.debug('Updates present: %r', are_updates_present)
    if are_updates_present:
        logger.info('Updates are present.')
        if gui.user_wants_to_update():
            logger.info('Performing auto-update in diff process.')
            utils.perform_update()
    else:
        logger.info('No updates are present.')


def main(installing=False):
    """Perform a client request to be logged in."""
    # pylint: disable=W0612
    app = QtGui.QApplication(sys.argv)
    # pylint: enable=W0612
    import qtreactor.qt4reactor
    qtreactor.qt4reactor.install()
    from ubuntuone_installer.gui.qt import gui
    from twisted.internet import reactor
    # All this has to be imported here because it installs a reactor
    from ubuntuone.platform.credentials import CredentialsManagementTool
    from ubuntuone_installer.logger import setup_logging
    logger = setup_logging('qt.gui')
    check_credentials(CredentialsManagementTool, gui, logger, installing)
    reactor.run()
