# -*- coding: utf-8 -*-

# Authors: Roberto Alsina <roberto.alsina@canonical.com>
#          Diego Sarmentero <diego.sarmentero@canonical.com>
#
# Copyright 2011 Canonical Ltd.
#
# This program is free software: you can redistribute it and/or modify it
# under the terms of the GNU General Public License version 3, as published
# by the Free Software Foundation.
#
# This program is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranties of
# MERCHANTABILITY, SATISFACTORY QUALITY, or FITNESS FOR A PARTICULAR
# PURPOSE.  See the GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License along
# with this program.  If not, see <http://www.gnu.org/licenses/>.

"""Page to list folders in a Ubuntu One account."""

import gettext

from PyQt4 import QtGui
from ubuntuone.controlpanel.gui.qt import preferences
from ubuntu_sso.qt.gui import SSOWizardPage

from ubuntuone_installer.gui.qt.ui import preferences_ui

_ = gettext.gettext


class PreferencesPage(SSOWizardPage):
    """Wizard page to list and manage an account's folders."""

    def __init__(self, parent=None):
        super(PreferencesPage, self).__init__(
            preferences_ui.Ui_Form(), None, parent)
        self.preferences_widget = preferences.PreferencesPanel()
        self.layout().addWidget(self.preferences_widget)
        self.preferences_widget.ui.apply_changes_button.hide()
        self.preferences_widget.ui.restore_defaults_button.hide()

    # Invalid name "initializePage"
    # pylint: disable=C0103

    def initializePage(self):
        self.wizard().setOption(QtGui.QWizard.HaveCustomButton1, True)
        self.wizard().setOption(QtGui.QWizard.HaveCustomButton2, True)
        # This is just to catch an exception thrown when nothing
        # is connected to the signal. It's not an exceptional
        # condition at all.
        try:
            self.wizard().customButtonClicked.disconnect()
        except TypeError:
            pass
        self.wizard()._next_id = None
        self.setButtonText(QtGui.QWizard.CustomButton1,
            _("Apply these settings >"))
        self.setButtonText(QtGui.QWizard.CustomButton2, _("Default settings"))

        self.wizard().setButtonLayout([
            QtGui.QWizard.BackButton,
            QtGui.QWizard.Stretch,
            QtGui.QWizard.CustomButton2,
            QtGui.QWizard.CustomButton1])
        self.wizard().button(QtGui.QWizard.CustomButton1).setDefault(True)
        self.wizard().button(QtGui.QWizard.CustomButton1).style().unpolish(
            self.wizard().button(QtGui.QWizard.CustomButton1))
        self.wizard().button(QtGui.QWizard.CustomButton1).style().polish(
            self.wizard().button(QtGui.QWizard.CustomButton1))

        self.wizard().customButtonClicked.connect(self._button_clicked)

    # pylint: enable=C0103

    def _button_clicked(self, btn):
        """Receive custom wizard buttons clicks."""
        if btn == QtGui.QWizard.CustomButton1:
            self.preferences_widget.on_apply_changes_button_clicked()
            self.cleanupPage()
            self.wizard().back()
        elif btn == QtGui.QWizard.CustomButton2:
            self.preferences_widget.on_restore_defaults_button_clicked()

    # Invalid name "cleanupPage"
    # pylint: disable=C0103
    def cleanupPage(self):
        """Execute this cleanup function when the back button is pressed."""
        self.wizard().setOption(QtGui.QWizard.HaveCustomButton1, False)
        self.wizard().setOption(QtGui.QWizard.HaveCustomButton2, False)
        self.wizard().setButtonLayout([
            QtGui.QWizard.BackButton,
            QtGui.QWizard.Stretch,
            QtGui.QWizard.NextButton])
        self.wizard().folders_page.initializePage()
    # pylint: enable=C0103
