# -*- coding: utf-8 -*-

# Authors: Roberto Alsina <roberto.alsina@canonical.com>
#
# Copyright 2011 Canonical Ltd.
#
# This program is free software: you can redistribute it and/or modify it
# under the terms of the GNU General Public License version 3, as published
# by the Free Software Foundation.
#
# This program is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranties of
# MERCHANTABILITY, SATISFACTORY QUALITY, or FITNESS FOR A PARTICULAR
# PURPOSE.  See the GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License along
# with this program.  If not, see <http://www.gnu.org/licenses/>.

"""The user interface for the Ubuntu One Installer."""

from PyQt4 import QtGui
from twisted.internet.defer import inlineCallbacks
from ubuntuone.controlpanel import backend

from ubuntuone_installer.gui import NEXT
from ubuntuone_installer.logger import setup_logging

# Invalid name logger
# pylint: disable=C0103
logger = setup_logging('qt.sync_now_or_later')
# pylint: enable=C0103


class SyncNowOrLaterPage(QtGui.QWizardPage):
    """User can choose whether to sync now, later, or selectively"""

    def __init__(self, parent=None):
        QtGui.QWizardPage.__init__(self, parent)
        self.has_cloud_folders = False
        self.cp_backend = None

    # Invalid names of Qt-inherited methods
    # pylint: disable=C0103

    def initializePage(self):
        """Setup UI details"""
        self.wizard().setOption(QtGui.QWizard.HaveCustomButton1, False)
        self.wizard().setOption(QtGui.QWizard.NoCancelButton, True)
        self.wizard()._next_id = None
        self.wizard().overlay.show()
        self.wizard().setButtonText(QtGui.QWizard.NextButton,
            NEXT)
        self.wizard().setButtonLayout([
            QtGui.QWizard.Stretch,
            QtGui.QWizard.NextButton])
        self.get_info()

    def nextId(self):
        """Go to the next page depending on the select field."""
        if self.has_cloud_folders:
            self.wizard().local_folders_page.has_back_button = True
            return self.wizard().folders_page_id
        else:
            self.wizard().local_folders_page.has_back_button = False
            return self.wizard().local_folders_page_id

    @inlineCallbacks
    def get_info(self):
        """Get folder information from CP backend."""
        # pylint: disable=W0702
        try:
            self.cp_backend = backend.ControlBackend()
            volumes_info = yield self.cp_backend.volumes_info()
        except:
            logger.exception("Error getting backend info:")
        else:
            counter = 0
            for _, _, volumes in volumes_info:
                counter += len(volumes)
            if counter > 1:
                # there are UDFs or shares, show cloud-to-computer
                self.has_cloud_folders = True
            else:
                self.has_cloud_folders = False
            self.wizard().next()
