# -*- coding: utf-8 -*-

# Authors: Diego Sarmentero <diego.sarmentero@canonical.com>
#
# Copyright 2011 Canonical Ltd.
#
# This program is free software: you can redistribute it and/or modify it
# under the terms of the GNU General Public License version 3, as published
# by the Free Software Foundation.
#
# This program is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranties of
# MERCHANTABILITY, SATISFACTORY QUALITY, or FITNESS FOR A PARTICULAR
# PURPOSE.  See the GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License along
# with this program.  If not, see <http://www.gnu.org/licenses/>.

"""Tests for the EnhancedCheckBox widget."""

import re

from PyQt4 import QtCore

from ubuntuone_installer.gui.qt import enhanced_check_box
from ubuntuone_installer.gui.qt.tests import BaseTestCase


class EnhancedCheckBoxTestCase(BaseTestCase):
    """Test the EnhancedCheckBox code."""

    def test_init(self):
        """Check the initial state of EnhancedCheckBox."""
        check = enhanced_check_box.EnhancedCheckBox("text")
        self.assertEqual(check.text(), "text")
        self.assertTrue(check.text_label.openExternalLinks())
        style_sheet = unicode(check.text_label.styleSheet())
        size = re.sub("\D", "", style_sheet)
        self.assertEqual(check.iconSize().width(), int(size))
        self.assertEqual(check.receivers(
            QtCore.SIGNAL('stateChanged(int)')), 1)

    def test_set_text(self):
        """Check if override setText and text methods works properly."""
        check = enhanced_check_box.EnhancedCheckBox()
        self.assertEqual(check.text_label.text(), "")
        check.setText("text")
        self.assertEqual(check.text(), "text")
        self.assertEqual(check.text(), check.text_label.text())
