# -*- coding: utf-8 -*-

# Authors: Roberto Alsina <roberto.alsina@canonical.com>
#
# Copyright 2011 Canonical Ltd.
#
# This program is free software: you can redistribute it and/or modify it
# under the terms of the GNU General Public License version 3, as published
# by the Free Software Foundation.
#
# This program is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranties of
# MERCHANTABILITY, SATISFACTORY QUALITY, or FITNESS FOR A PARTICULAR
# PURPOSE.  See the GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License along
# with this program.  If not, see <http://www.gnu.org/licenses/>.

"""Tests for the sync_now_or_later page."""

import os

from PyQt4 import QtGui
from twisted.internet import defer

from ubuntuone_installer.gui import NEXT
from ubuntuone_installer.gui.qt import sync_now_or_later
from ubuntuone_installer.gui.qt.tests import BaseTestCase
from ubuntuone_installer.gui.qt.tests.test_gui import FakeMainWindow
from ubuntuone_installer.gui.qt.tests.test_local_folders import (
    FakeCPBackend,
)


class FakeEmptyCPBackend(FakeCPBackend):
    """A CP backend that returns only one folder."""
    def volumes_info(self, *args):
        """Fake volumes info."""
        return defer.succeed(((None, None,
            [
            {
                'type': u'ROOT',
                'path': os.path.expanduser(u'~/Ubuntu One'),
                'volume_id': 'asdfgh',
                'subscribed': True,
            }]),))


class SyncNowOrLaterTestCase(BaseTestCase):
    """Test the sync_now_or_later page."""

    class_ui = sync_now_or_later.SyncNowOrLaterPage

    def setUp(self):
        """Initialize tests."""
        super(SyncNowOrLaterTestCase, self).setUp()
        self.main_window = FakeMainWindow()
        self.patch(self.ui, "wizard", lambda: self.main_window)
        self.patch(sync_now_or_later.backend, "ControlBackend", FakeCPBackend)

    @defer.inlineCallbacks
    def test_has_folders_in_cloud(self):
        """test behaviour when the user has folders in the cloud."""
        yield self.ui.get_info()
        self.assertTrue(self.ui.has_cloud_folders)

    @defer.inlineCallbacks
    def test_has_no_folders_in_cloud(self):
        """test behaviour when the user has no folders in the cloud."""
        self.patch(sync_now_or_later.backend,
            "ControlBackend", FakeEmptyCPBackend)
        yield self.ui.get_info()
        self.assertFalse(self.ui.has_cloud_folders)

    def test_has_cloud_folders_next(self):
        """With cloud folders, next page is folders."""
        self.ui.has_cloud_folders = True
        self.assertEqual(self.ui.nextId(), FakeMainWindow.folders_page_id)
        self.assertTrue(self.main_window.local_folders_page.has_back_button)

    def test_has_no_cloud_folders_next(self):
        """With cloud folders, next page is folders."""
        self.ui.has_cloud_folders = False
        self.assertEqual(self.ui.nextId(),
            FakeMainWindow.local_folders_page_id)
        self.assertFalse(self.main_window.local_folders_page.has_back_button)

    def test_status_after_initialize(self):
        """Test that everything is initialized correctly."""
        self.assertEqual(self.ui.wizard().overlay.show_counter, 0)
        self.ui.initializePage()
        self.assertEqual(self.ui.wizard().overlay.show_counter, 1)
        self.assertEqual(self.ui.wizard().overlay.hide_counter, 0)
        self.assertEqual(self.ui.wizard().button_texts,
            [(QtGui.QWizard.NextButton, NEXT)])
