# -*- coding: utf-8 -*-

# Authors: Diego Sarmentero <diego.sarmentero@canonical.com>
#
# Copyright 2011 Canonical Ltd.
#
# This program is free software: you can redistribute it and/or modify it
# under the terms of the GNU General Public License version 3, as published
# by the Free Software Foundation.
#
# This program is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranties of
# MERCHANTABILITY, SATISFACTORY QUALITY, or FITNESS FOR A PARTICULAR
# PURPOSE.  See the GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License along
# with this program.  If not, see <http://www.gnu.org/licenses/>.

"""Tests for the platform specific functions."""

import os
import subprocess

from ubuntuone_installer.gui.qt import utils
from ubuntuone_installer.gui.qt.tests import BaseTestCase


class StartControlPanelTestCase(BaseTestCase):

    """Test the start of the control panel."""

    def test_start_control_panel(self):
        """The proper process is started."""
        self.patch(subprocess, "Popen", self._set_called)

        utils.start_control_panel()

        expected = ((['ubuntuone-control-panel-qt'],), {})
        self.assertEqual(self._called, expected)


class DefaultFoldersTestCase(BaseTestCase):

    """Test the default suggested UDFs."""

    def test_special_folders(self):
        """Test that default_folders does the right thing."""
        folders = utils.default_folders()
        self.assertEqual(len(folders), 3)
        self.assertEqual(folders, [os.path.abspath(f) for f in folders])
        # pylint: disable=W0404
        docs = os.path.expanduser("~/Documents")
        music = os.path.expanduser("~/Music")
        pictures = os.path.expanduser("~/Pictures")
        expected = [docs, music, pictures]
        self.assertEqual(sorted(folders), sorted(expected))


class OldBetaUpdateTestCase(BaseTestCase):

    """Test the update from the old beta."""

    def test_is_old_beta_installed(self):
        """Test the function used to know if it is installed."""
        self.assertFalse(utils.is_old_beta_installed(), 'Should always be'
                ' false.')

    def test_perform_update(self):
        """Test the function that performs the update."""
        self.assertEqual(None, utils.perform_update())
